
# Blind Chromatic Aberration Correction with False Color Filtering

This is a non-official Cython-based implementation of the IEEE Transactions on Image
Processing 2013 article *Correction of Axial and Lateral Chromatic Aberration With False Color Filter* by
Joonyoung Chang, Hee Kang and Moon Gi Kang.

The method consists in a 1D filter independently run on the columns and rows of an image containing chromatic 
aberrations. Merging the horizontally and vertically filtered outputs yields the final restored image. Our
implementation leverages the multi-threading abilities of Cython to achieve restoration on large images in less
than 1 second.

This implementation is part of an IPOL paper describing in the detail the method. If this code is useful to your 
research please cite our paper.

### Testing the code

You can test the code with a test JPEG image containing chromatic aberrations. First, compile Cython code with
```bash
python setup.py install --user
```

Second, you can restore the image with the command line:
```bash
python main.py --input PATH/TO/IMAGE.png --output PATH/TO/SAVED_IMAGE.png
```

This will save a 8-bit PNG file containing the restored image. Modify the main.py file if you want to save in 16 bits instead
(preferable for linear raw images).

### Requirements

Please run the pip install command below to install the requirements:
```bash
pip install requirements.txt
```

### Description

The code contains two main modules: filter.py that is a numpy-pure implemention of the paper (and is extremely slow),
and filter_cython.pyx that contains the sources for the Cython implementation (recommanded).

After installation/compilation, you can import in any project this code by importing the package and use it as follows
```python
import filter_cython

##########################################
# ... define the variables like in main.py
##########################################

impred, im_TI, im_FC = filter_cython.chromatic_removal(img, L_hor, L_ver, rho, tau, alpha_R, alpha_B, beta_R, beta_B, gamma_1, gamma_2)
```

Please refer to main.py to see an example of use.

### Contact 

If you encounter any problem with the code, please contact me at <thomas.eboli@ens-paris-saclay.fr>.
