# Copyright 2022 Thomas Eboli (thomas.eboli12@gmail.com)
# 
# Permission is hereby granted, free of charge, to any person obtaining 
# a copy of this software and associated documentation files (the "Software"), 
# to deal in the Software without restriction, including without limitation 
# the rights to use, copy, modify, merge, publish, distribute, sublicense, 
# and/or sell copies of the Software, and to permit persons to whom the 
# Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included 
# in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
# DEALINGS IN THE SOFTWARE.


from setuptools import Extension, setup, find_packages
from Cython.Build import cythonize
import numpy as np




setup(
    name='chromatic_aberration_filtering',
    version="0.1.0",
    packages=find_packages(),
    author="Thomas Eboli",
    author_email="thomas.eboli@ens-paris-saclay.fr",
    url="https://github.com/teboli/chromatic_aberration_filtering",
    description="A Python implementation of [Cheng et al., TIP'13]",
    include_dirs=np.get_include(),
    ext_modules=
        cythonize(Extension('filter_cython',
                  sources=['filter_cython.pyx'],
                  extra_compile_args=['-O3', '-ffast-math', '-march=native', '-fopenmp'],
                  extra_link_args=['-fopenmp'],
                  language='c++')
                  ),
    classifiers=[
        "Programming Language :: Cython",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX",
        "Topic :: Scientific/Engineering :: Image Processing",
    ],
)

